
/* Chrysalide - Outil d'analyse de fichiers binaires
 * ##FILE## - traduction d'instructions ARMv7
 *
 * Copyright (C) 2015 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */


@title CDP, CDP2

@desc Coprocessor Data Processing tells a coprocessor to perform an operation that is independent of ARM core registers and memory. If no coprocessor can execute the instruction, an Undefined Instruction exception is generated. This is a generic coprocessor instruction. Some of the fields have no functionality defined by the architecture and are free for use by the coprocessor instruction set designer. These are the opc1, opc2, CRd, CRn, and CRm fields. However, coprocessors CP8-CP15 are reserved for use by ARM, and this manual defines the valid CDP and CDP2 instructions when coproc is in the range p8-p15. For more information see Coprocessor support on page A2-94.

@encoding (T1) {

	@word 1 1 1 0 1 1 1 0 opc1(4) CRn(4) CRd(4) coproc(4) opc2(3) 0 CRm(4)

	@syntax <cp> <undef_opc1> <creg_D> <creg_N> <creg_M> <undef_opc2>

	@conv {

		cp = CoProcessor(coproc)
		undef_opc1 = RawValue(opc1)
		creg_D = CRegister(CRd)
		creg_N = CRegister(CRn)
		creg_M = CRegister(CRm)
		undef_opc2 = RawValue(opc2)

	}

}

@encoding (A1) {

	@word cond(4) 1 1 1 0 opc1(4) CRn(4) CRd(4) coproc(4) opc2(3) 0 CRm(4)

	@syntax <cp> <undef_opc1> <creg_D> <creg_N> <creg_M> <undef_opc2>

	@conv {

		cp = CoProcessor(coproc)
		undef_opc1 = RawValue(opc1)
		creg_D = CRegister(CRd)
		creg_N = CRegister(CRn)
		creg_M = CRegister(CRm)
		undef_opc2 = RawValue(opc2)

	}

	@rules {

		chk_call StoreCondition(cond)

	}

}

@encoding (T2) {

	@word 1 1 1 1 1 1 1 0 opc1(4) CRn(4) CRd(4) coproc(4) opc2(3) 0 CRm(4)

	@syntax "cdp2" <cp> <undef_opc1> <creg_D> <creg_N> <creg_M> <undef_opc2>

	@conv {

		cp = CoProcessor(coproc)
		undef_opc1 = RawValue(opc1)
		creg_D = CRegister(CRd)
		creg_N = CRegister(CRn)
		creg_M = CRegister(CRm)
		undef_opc2 = RawValue(opc2)

	}

}

@encoding (A2) {

	@word 1 1 1 1 1 1 1 0 opc1(4) CRn(4) CRd(4) coproc(4) opc2(3) 0 CRm(4)

	@syntax "cdp2" <cp> <undef_opc1> <creg_D> <creg_N> <creg_M> <undef_opc2>

	@conv {

		cp = CoProcessor(coproc)
		undef_opc1 = RawValue(opc1)
		creg_D = CRegister(CRd)
		creg_N = CRegister(CRn)
		creg_M = CRegister(CRm)
		undef_opc2 = RawValue(opc2)

	}

}

