
/* Chrysalide - Outil d'analyse de fichiers binaires
 * register.h - prototypes pour les aides auxiliaires relatives aux registres x86
 *
 * Copyright (C) 2012-2017 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef _ARCH_X86_REGISTER_H
#define _ARCH_X86_REGISTER_H


#include <glib-object.h>
#include <stdbool.h>


#include "../archbase.h"
#include "../../glibext/gbufferline.h"



#define G_TYPE_X86_REGISTER               g_x86_register_get_type()
#define G_X86_REGISTER(obj)               (G_TYPE_CHECK_INSTANCE_CAST((obj), g_x86_register_get_type(), GX86Register))
#define G_IS_X86_REGISTER(obj)            (G_TYPE_CHECK_INSTANCE_TYPE((obj), g_x86_register_get_type()))
#define G_X86_REGISTER_CLASS(klass)       (G_TYPE_CHECK_CLASS_CAST((klass), G_TYPE_X86_REGISTER, GX86RegisterClass))
#define G_IS_X86_REGISTER_CLASS(klass)    (G_TYPE_CHECK_CLASS_TYPE((klass), G_TYPE_X86_REGISTER))
#define G_X86_REGISTER_GET_CLASS(obj)     (G_TYPE_INSTANCE_GET_CLASS((obj), G_TYPE_X86_REGISTER, GX86RegisterClass))


/* Représentation d'un registre x86 (instance) */
typedef struct _GX86Register GX86Register;

/* Représentation d'un registre x86 (classe) */
typedef struct _GX86RegisterClass GX86RegisterClass;


/* Indique le type défini pour une représentation d'un registre x86. */
GType g_x86_register_get_type(void);

/* Crée une réprésentation de registre x86. */
GX86Register *g_x86_register_new(MemoryDataSize, bin_t);

/* Compare un registre avec un autre. */
bool g_x86_register_compare(const GX86Register *, const GX86Register *);

/* Traduit un registre en version humainement lisible. */
void g_x86_pool_operand_print(const GX86Register *, GBufferLine *, AsmSyntax);

/* Indique si le registre correspond à ebp ou similaire. */
bool g_x86_register_is_base_pointer(const GX86Register *);

/* Indique si le registre correspond à esp ou similaire. */
bool g_x86_register_is_stack_pointer(const GX86Register *);



#endif  /* _ARCH_X86_REGISTER_H */
